==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fi\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Linja"

, "Caller Id"
: "Soittajan numero"

, "Start"
: "Aloita"

, "Connected"
: "Yhdistetty"

, "Disconnected"
: "Katkaistu"

, "Duration"
: "Kesto"

, "Ringing"
: "Soi"

, "Direction"
: "Suunta"

, "Source"
: "Lähde"

, "Destination"
: "Kohde"

, "Phone"
: ""

, "Phones"
: "Puhelimet"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Numero"

, "Cancel"
: "Peruuta"

, "Dial"
: "Soita"

, "Error"
: "Virhe"

, "Not possible to dial."
: "Valinta ei onnistu."

, "Edit phone settings"
: "Muokkaa puhelin asetuksia"

, "Dial number"
: "Valitse numero"

, "Initiate a new outgoing call"
: "Aloita uusi puhelu"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Yhteyshenkilö"

, "Work"
: "Työ"

, "Home"
: "Koti"

, "Cell"
: "Matkapuhelin"

, "Cell private"
: "Matkapuhelin koti"

, "Incoming call"
: "Tuleva puhelu"

, "Outgoing call"
: "Lähtevä puhelu"

, "unknown number"
: "Tuntematon numero"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Tuleva puhelu"

, "Outgoing call"
: "Lähtevä puhelu"

, "unknown number"
: "Tuntematon numero"

, "Phone"
: ""

, "Line"
: "Linja"

, "Number"
: "Numero"

, "Cancel"
: "Peruuta"

, "Dial"
: "Soita"

, "Error"
: "Virhe"

, "Not possible to dial."
: "Valinta ei onnistu."

, "Call contact"
: "Yhteyshenkilö"

, "Work"
: "Työ"

, "Home"
: "Koti"

, "Cell"
: "Matkapuhelin"

, "Cell private"
: "Matkapuhelin koti"

, "Edit phone settings"
: "Muokkaa puhelin asetuksia"

, "Dial number"
: "Valitse numero"

, "Initiate a new outgoing call"
: "Aloita uusi puhelu"

, "Phones"
: "Puhelimet"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Soittajan numero"

, "Start"
: "Aloita"

, "Connected"
: "Yhdistetty"

, "Disconnected"
: "Katkaistu"

, "Duration"
: "Kesto"

, "Ringing"
: "Soi"

, "Direction"
: "Suunta"

, "Source"
: "Lähde"

, "Destination"
: "Kohde"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
